pub trait Component:
Send
+ Sync
+ 'static { }Expand description
A component that can be attached to an entity in a crate::World
pub trait Component:
Send
+ Sync
+ 'static { }A component that can be attached to an entity in a crate::World