macro_rules! component_id {
($type: ty) => { ... };
($value: expr) => { ... };
}Expand description
Get the ComponentKey of a component type, can accept either a type or an expression
macro_rules! component_id {
($type: ty) => { ... };
($value: expr) => { ... };
}Get the ComponentKey of a component type, can accept either a type or an expression